from apipkg import initpkg as __initpkg

# fmt: off
__initpkg(__name__, {
    "navigate": "navmazing",
    "ui": {
        "core": "widgetastic.widget",  # todo: html widget library here, limit to base
        "patternfly": "widgetastic_patternfly",  # dito

        "View": "widgetastic.widget:View",
        "Browser": "widgetastic.browser:Browser",
        "DefaultPlugin": "widgetastic.browser:DefaultPlugin"
    },
})



import inspect
import taretto
import pytest


@pytest.mark.parametrize(
    "mod",
    [taretto.navigate, taretto.ui, taretto.ui.core, taretto.ui.patternfly],
    ids=lambda mod: mod.__name__,
)
def test_module_aliases(mod):
    print(mod, dir(mod))


@pytest.mark.parametrize(
    "mod, classname",
    [
        (taretto.ui, "View"),
        (taretto.ui, "Browser"),
        (taretto.ui, "DefaultPlugin"),
        (taretto.ui.patternfly, "VerticalNavigation"),
    ],
    ids=lambda mod: mod.__name__,
)
def test_aliased_classes(mod, classname):
    klass = getattr(mod, classname)
    assert inspect.isclass(klass)



from sentaku import ImlementationContext as _SentakuImplementationContext
from sentaku import ContextualMethod, ContextualProperty, Element, Collection

__all__ = ["ContextualMethod", "ContextualProperty", "Element", "Collection"]


# subclass to have a custom dectate registration point
class ImplementationContext(_SentakuImplementationContext):
    pass
